@@ -11,7 +11,7 @@ from typing import Optional, List
 from figcli.svcs.setup import FiggySetup
 
 from figcli.config import *
-from figcli.input.input import Input
+from figcli.io.input import Input
 from figcli.models.assumable_role import AssumableRole
 from figcli.models.defaults.defaults import CLIDefaults
 from figcli.models.role import Role
